from setuptools import setup, find_packages, Extension
from Cython.Distutils import build_ext

import os.path
import subprocess

def _get_pkgconfig_output(cmd, pkg):
    proc = subprocess.Popen(['pkg-config', cmd, pkg],
                            stdout=subprocess.PIPE,
                            stderr=subprocess.PIPE)
    return proc.communicate()[0].replace('\\"', '').rstrip().decode('utf-8')

cflags = _get_pkgconfig_output('--cflags', 'opencv')
libs = _get_pkgconfig_output('--libs', 'opencv')

ext_opts = {}
if cflags:
    ext_opts["include_dirs"] = []
    for i in cflags.split(' '):
        ext_opts["include_dirs"].append(i[2:])
if libs:
    ext_opts['libraries'] = []
    ext_opts['library_dirs'] = []
    for l in libs.split(' '):
        ldir = os.path.dirname(l)
        if ldir not in ext_opts['library_dirs']:
            ext_opts['library_dirs'].append(ldir)
        ext_opts['libraries'].append(os.path.basename(l)[3:-3])
    if not ext_opts['libraries']:
        ext_opts.pop('libraries')

cvtempl = Extension('motmot.fview_head_track.cvtempl',
                    ['src/cvtempl.pyx','src/libcvtempl.cpp'],
                    language='c++',
                    **ext_opts)

setup(
    name='motmot.fview_head_track',
    description='head tracking plugin for fview',
    version='0.0.1',
    namespace_packages = ['motmot'],
    packages = ['motmot', 'motmot.fview_head_track'],
    author='John Stowers',
    author_email='john.stowers@gmail.com',
    entry_points = {
        'motmot.fview.plugins':'fview_head_track = motmot.fview_head_track.fview_head_track:FviewHeadTrack',
    },
    ext_modules=[cvtempl],
    cmdclass={'build_ext': build_ext}
)
