#cython: embedsignature=True

import numpy as np

cimport numpy as np
cimport cython

from libcpp.string cimport string
from libcpp cimport bool

from cython.operator import dereference as deref

cdef extern from "libcvtempl.h":
    bool is_gpu_supported()
    cdef cppclass Matcher:
        Matcher(int id, int method)
        void load_template(string tmpl)
        void set_template(int height, int width, void *data)
        void match_template(int height, int width, void *data, int *loc_x, int *loc_y, double *value, bool *value_ok)
        void match_template_both_ways(int height, int width, void *data, int *loc_x, int *loc_y, double *value, bool *value_ok, bool *flipped)


def is_available():
    return is_gpu_supported()

cdef class GPUTemplateMatcher:
    """
    Segmentation class for Sample Consensus methods and models
    """
    cdef Matcher *me

    def __cinit__(self, int id=0, int method=1):
        self.me = new Matcher(id, method)
    def __dealloc__(self):
        del self.me

    def load_template(self, char *tmpl):
        cdef string s = string(tmpl)
        self.me.load_template(s)

    @cython.boundscheck(False)
    @cython.wraparound(False)
    def set_template(self, np.ndarray[dtype=np.uint8_t, ndim=2, mode="c"] input not None):
        cdef int height, width
        height, width = input.shape[0], input.shape[1]
        self.me.set_template(height, width, &input[0,0])

    @cython.boundscheck(False)
    @cython.wraparound(False)
    def match_template(self, np.ndarray[dtype=np.uint8_t, ndim=2, mode="c"] input not None):
        cdef double value
        cdef bool value_ok
        cdef int height, width, x, y
        height, width = input.shape[0], input.shape[1]
        self.me.match_template(height, width, &input[0,0], &x, &y, &value, &value_ok)
        return (x,y),value,value_ok

    @cython.boundscheck(False)
    @cython.wraparound(False)
    def match_template_both_ways(self, np.ndarray[dtype=np.uint8_t, ndim=2, mode="c"] input not None):
        cdef double value
        cdef bool value_ok, flipped
        cdef int height, width, x, y
        height, width = input.shape[0], input.shape[1]
        self.me.match_template_both_ways(height, width, &input[0,0], &x, &y, &value, &value_ok, &flipped)
        return (x,y),value,value_ok,flipped

    res = None



